{% extends 'twitter/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'twitter:home' %}">Twitter</a></li>
    <li class="breadcrumb-item active">{{ twitter_user }}</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Tweets by {{ twitter_user.name }}
        {% endblock %}
        <small class="text-muted">{{ twitter_user }}</small>
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'twitter/includes/user.html' with user=twitter_user account=account perms=perms only %}

            {% include 'twitter/includes/annual_tweet_counts.html' with user=twitter_user only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'twitter/includes/nav_tabs.html' with user=twitter_user active='tweets' only %}

            {% if twitter_user.is_private %}
                <p>This user is private.</p>
            {% endif %}

            {% include 'twitter/includes/tweet_list.html' with tweet_list=tweet_list page_obj=page_obj perms=perms only %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}

