{% comment %}
A single Photo as the contents of a Bootstrap media object.
For displaying in a list as individual photos, rather than in columns.

Expects:
photo - A Photo object.

{% endcomment %}

{% load ditto_core %}

<div class="d-flex mr-3">
    <a href="{% url 'flickr:photo_detail' nsid=photo.user.nsid flickr_id=photo.flickr_id %}" class="flickr-photo-img">
        <img src="{{ photo.small_url }}" width="{{ photo.small_width }}" height="{{ photo.small_height }}" alt="">
    </a>
</div>

<div class="media-body">
    <h3 class="h6 flickr-photo-title">
        <a href="{% url 'flickr:photo_detail' nsid=photo.user.nsid flickr_id=photo.flickr_id %}">{{ photo.title }}</a>
    </h3>
    <p class="mb-0 flickr-photo-summary">{{ photo.summary|safe }}</p>
    <p class="flickr-photo-muted">
        <small class="text-muted">
            Uploaded by <a href="{% url 'flickr:user_detail' nsid=photo.user.nsid %}" title="More photos by this person">{{ photo.user.name }}</a> at {% display_time photo.post_time link_to_day=True granularity=photo.taken_granularity %}
        </small>
    </p>
</div>

