# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-12 10:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('lastfm', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scrobble',
            name='account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='scrobbles', to='lastfm.Account'),
        ),
    ]
