{% extends 'ditto/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'ditto:tag_list' %}">Tags</a></li>
    <li class="breadcrumb-item active">{{ tag }}</li>
{% endblock %}

{% block content %}
    <h1 class="my-4">
        {% block title %}
            Things tagged with “{{ tag }}”
        {% endblock %}
    </h1>

    {% if pinboard_bookmark_list|length %}
        <h2>Pinboard Bookmarks</h2>

        {% include 'pinboard/includes/bookmark_list.html' with bookmark_list=pinboard_bookmark_list page_obj=False only %}
    {% endif %}

{% endblock content %}

