{% comment %}
For displaying an aggregated list of different kinds of Items - Photos,
Bookmarks or Tweets.

Expects:

* object_list - A list containing individual Photo, Bookmark or Tweet objects.

{% endcomment %}
<hr>
<div class="flickr-photos twitter-tweets pinboard-bookmarks">
    {% for item in object_list %}

        {% if item.ditto_item_name == 'flickr_photo' %}
            <div class="media mt-0 flickr-photo">
                {% include 'flickr/includes/photo.html' with photo=item only %}
        {% elif item.ditto_item_name == 'lastfm_scrobble' %}
            <div class="media mt-0 lastfm-scrobble">
                {% include 'lastfm/includes/scrobble.html' with scrobble=item only %}
        {% elif item.ditto_item_name == 'pinboard_bookmark' %}
            <div class="media mt-0 pinboard-bookmark">
                {% include 'pinboard/includes/bookmark.html' with bookmark=item only %}
        {% elif item.ditto_item_name == 'twitter_tweet' %}
            <div class="media mt-0 twitter-tweet">
                {% include 'twitter/includes/tweet.html' with tweet=item only %}
        {% endif %}
            </div>
            <hr>
    {% endfor %}
</div>

