{% extends 'twitter/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item active">Twitter</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Twitter
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'ditto/includes/account_list.html' with account_list=account_list service_name='Twitter' only %}

            {% load l10n %}
            <div class="card mb-3">
                <ul class="list-group list-group-flush twitter-user-counts">
                    <li class="list-group-item">
                        {{ page_obj.paginator.count|localize }} tweet{{ page_obj.paginator.count|pluralize }}
                    </li>
                </ul>
            </div>

            {% include 'twitter/includes/annual_tweet_counts.html' only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'twitter/includes/nav_tabs.html' with active='tweets' only %}

            {% include 'twitter/includes/tweet_list.html' with tweet_list=tweet_list page_obj=page_obj perms=perms only %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}

