{% comment %}
For displaying a series of separate lists of different items - Photos, Bookmarks or Tweets.

Expects to be in context.

May specifically have:
* view - 'list' (a generic list), 'day' or 'detail'.

{% endcomment %}

{% if flickr_photo_list and flickr_photo_list|length > 0 %}

    <h2 class="mb-4">
        <a href="{% url 'flickr:home' %}">
            Flickr photos
            {% if order == 'taken' %}
                (taken)
            {% elif view == 'day' %}
                (uploaded)
            {% endif %}
        </a>
    </h2>

    {% include 'flickr/includes/photo_columns.html' with order=order photo_list=flickr_photo_list view=view %}

{% endif %}

{% if lastfm_scrobble_list and lastfm_scrobble_list|length > 0 %}

    <h2>
        <a href="{% url 'lastfm:home' %}">Last.fm scrobbles</a>
    </h2>

    {% include 'lastfm/includes/scrobble_list.html' with scrobble_list=lastfm_scrobble_list view=view %}

{% endif %}

{% if pinboard_bookmark_list and pinboard_bookmark_list|length > 0 %}

    <h2>
        <a href="{% url 'pinboard:home' %}">Pinboard bookmarks</a>
    </h2>

    {% include 'pinboard/includes/bookmark_list.html' with bookmark_list=pinboard_bookmark_list view=view %}

{% endif %}

{% if twitter_tweet_list and twitter_tweet_list|length > 0 %}

    <h2>
        <a href="{% url 'twitter:home' %}">Twitter tweets</a>
    </h2>

    {% include 'twitter/includes/tweet_list.html' with tweet_list=twitter_tweet_list view=view %}

{% endif %}

{% if twitter_favorite_list and twitter_favorite_list|length > 0 %}

    <h2>
        <a href="{% url 'twitter:favorite_list' %}">Liked tweets</a>
    </h2>

    {% include 'twitter/includes/tweet_list.html' with tweet_list=twitter_favorite_list view=view %}

{% endif %}



