{% extends 'pinboard/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'pinboard:home' %}">Pinboard</a></li>
    <li class="breadcrumb-item active">Tags</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            The most common Pinboard tags
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'ditto/includes/account_list.html' with account_list=account_list service_name='Pinboard' only %}
        </div> <!-- .col -->

        <div class="col-md-9">

            {% if tag_list|length == 0 %}
                <p>There are no tags in use.</p>
            {% else %}
                {% load l10n %}
                <ol>
                    {% for tag in tag_list %}
                        <li>
                            <a href="{% url 'pinboard:tag_detail' slug=tag.slug %}">
                                {{ tag.name }}
                            </a>
                            <small>({{ tag.num_times|localize }})</small>
                        </li>
                    {% endfor %}
                </ol>
            {% endif %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}

