{% extends 'ditto/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item active">Tags</li>
{% endblock %}

{% block content %}
    <h1 class="my-4">
        {% block title %}
            Tags
        {% endblock %}
    </h1>

    <p>This page left intentionally blank for now.</p>

{% endblock content %}

