{% comment %}

Expects:
 * bookmark_list, a queryset of Bookmarks.
 * page_obj, optional, a DiggPaginator instance or False (default).
 * perms - The Django perms object.
 * view - 'list' (a generic list), 'detail' or 'day'.

{% endcomment %}

{% if bookmark_list|length > 0 %}
    {% if page_obj|default:False and page_obj.number > 1 %}
        {% include 'ditto/includes/pagination.html' with page_obj=page_obj only %}
    {% endif %}

    <hr>
    <div class="pinboard-bookmarks">
        {% for bookmark in bookmark_list %}
            <div class="media pinboard-bookmark">
                {% include 'pinboard/includes/bookmark.html' with bookmark=bookmark view=view perms=perms only %}
            </div>
            <hr>
        {% endfor %}
    </div>

    {% if page_obj|default:False %}
        {% include 'ditto/includes/pagination.html' with page_obj=page_obj only %}
    {% endif %}

{% else %}
    <p>There are no bookmarks to show.</p>
{% endif %}

