# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-03 13:01
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('twitter', '0038_tweet_retweeted_status_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='media',
            name='tweets',
            field=models.ManyToManyField(to='twitter.Tweet'),
        ),
        migrations.AlterField(
            model_name='media',
            name='tweet',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='temporary_name', to='twitter.Tweet'),
        ),
    ]
