{% extends 'pinboard/base.html' %}
{% load l10n %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'pinboard:home' %}">Pinboard</a></li>
    <li class="breadcrumb-item"><a href="{% url 'pinboard:account_detail' username=account.username %}">{{ account.username }}</a></li>
    <li class="breadcrumb-item active">To read</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Pinboard “to read” by {{ account.username }}
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            <div class="card mb-3">
                <div class="card-body">
                    {{ page_obj.paginator.count|localize }} bookmark{{ page_obj.paginator.count|pluralize }} marked “to&nbsp;read”
                </div>
                {% if account.is_active %}
                    <ul class="list-group list-group-flush">
                        <li class="list-group-item">
                            <a href="{{ account.url }}">At Pinboard.in</a>
                        </li>
                    </ul>
                {% endif %}
            </div>

            {% include 'pinboard/includes/annual_bookmark_counts.html' with account=account only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'pinboard/includes/nav_tabs.html' with account=account active='toread' only %}

            {% include 'pinboard/includes/bookmark_list.html' with bookmark_list=bookmark_list page_obj=page_obj perms=perms only %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}

