# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-03 16:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('flickr', '0012_auto_20160503_1457'),
    ]

    operations = [
        migrations.AddField(
            model_name='photoset',
            name='photos_raw',
            field=models.TextField(blank=True, help_text='The raw JSON from the API listing the photos.'),
        ),
    ]
