{% comment %}
Display next/prev day links.

Expects:

next -- date.
previous -- date.
ditto_app_slug -- eg 'twitter' or 'flickr'.
ditto_variety_slug -- eg 'tweets' or 'likes'.

Might need to refactor or copy this for month/year pages?

{% endcomment %}
<nav class="my-4 nextprev">
    <p class="row">
        {% if previous %}
            <span class="col-6">
                <a href="{% url 'ditto:day_archive' year=previous|date:'Y' month=previous|date:'m' day=previous|date:'d' app=ditto_app_slug variety=ditto_variety_slug %}" class="btn btn-outline-primary">
                    &larr; {{ previous|date:'j M Y' }}
                </a>
            </span>
        {% endif %}
        {% if next %}
            <span class="col-6{% if not previous %} offset-6{% endif %}">
                <a href="{% url 'ditto:day_archive' year=next|date:'Y' month=next|date:'m' day=next|date:'d' app=ditto_app_slug variety=ditto_variety_slug %}" class="btn btn-outline-primary float-right">
                    {{ next|date:'j M Y' }} &rarr;
                </a>
            </span>
        {% endif %}
    </p>
</nav>

