# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-07-13 11:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twitter', '0048_auto_20160615_1045'),
    ]

    operations = [
        migrations.AlterField(
            model_name='media',
            name='aspect_ratio',
            field=models.CharField(blank=True, help_text='eg, "4:3" or "16:9"', max_length=21),
        ),
        migrations.AlterField(
            model_name='media',
            name='dash_url',
            field=models.URLField(blank=True, verbose_name='MPEG-DASH URL (.mpd, streaming)'),
        ),
        migrations.AlterField(
            model_name='media',
            name='xmpeg_url',
            field=models.URLField(blank=True, verbose_name='X-MPEG URL (HLS, .m3u8, streaming'),
        ),
    ]
