{% extends 'ditto/base.html' %}

{% block pinboard_nav_active %}active{% endblock %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item active"><a href="{% url 'pinboard:home' %}">Pinboard</a></li>
{% endblock %}

