{% extends 'flickr/base.html' %}
{% load l10n %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'flickr:home' %}">Flickr</a></li>
    <li class="breadcrumb-item"><a href="{% url 'flickr:user_detail' nsid=user.nsid %}">{{ user.name }}</a></li>
    <li class="breadcrumb-item active">Albums</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Photo albums by {{ user.name }}
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'flickr/includes/user.html' with user=flickr_user account=account perms=perms only %}

            {% include 'flickr/includes/annual_photo_counts.html' with user=flickr_user only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'flickr/includes/nav_tabs.html' with user=flickr_user active='photosets' only %}

            {% include 'flickr/includes/photoset_list.html' with photoset_list=photoset_list only %}
        </div> <!-- .col -->
    </div> <!-- .row -->


{% endblock content %}


