{% comment %}
Displays the 'Sort by:  Uploaded time  Taken time' photo list navigation.

Expects:
* request -- The Request object.
* order -- A string indicating the current ordering. 'uploaded' or 'taken'.
{% endcomment %}

{% load ditto_core %}

<nav>
	<ul class="nav justify-content-end mb-3">
		<li class="nav-item">
			<span class="nav-link">Sort:</span>
		</li>
		<li class="nav-item">
			{% if order == 'uploaded' %}
				<strong class="nav-link">Uploaded time</strong>
			{% else %}
			<a class="nav-link" href="?{% query_string 'order' 'uploaded' %} ">Uploaded time</a>
			{% endif %}
		</li>
		<li class="nav-item">
			{% if order == 'taken' %}
				<strong class="nav-link">Taken time</strong>
			{% else %}
				<a class="nav-link" href="?{% query_string 'order' 'taken' %}">Taken time</a>
			{% endif %}
		</li>
	</ul>
</nav>

