{% extends 'flickr/base.html' %}
{% load l10n %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'flickr:home' %}">Flickr</a></li>
    <li class="breadcrumb-item active">Albums</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Photo albums
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'ditto/includes/account_list.html' with account_list=account_list service_name='Flickr' only %}

            {% load l10n %}
            <div class="card mb-3">
                <ul class="list-group list-group-flush flickr-user-counts">
                    <li class="list-group-item">
                        {{ photoset_list.count|localize }} album{{ photoset_list.count|pluralize }}
                    </li>
                </ul>
            </div>
            <div class="card mb-3">
                <div class="card-body">
                    <p class="card-text">
                        <a href="{% url 'flickr:tag_list' %}">The most common tags</a>
                    </p>
                </div>
            </div>
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'flickr/includes/nav_tabs.html' with active='photosets' only %}

            {% include 'flickr/includes/photoset_list.html' with photoset_list=photoset_list only %}
        </div> <!-- .col -->
    </div> <!-- .row -->


{% endblock content %}


