{% extends 'flickr/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'flickr:home' %}">Flickr</a></li>
    <li class="breadcrumb-item active">{{ flickr_user }}</li>
{% endblock %}

{% block content %}

    <h1 class="my-4">
        {% block title %}
            Photos by {{ flickr_user.name }}
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'flickr/includes/user.html' with user=flickr_user account=account perms=perms only %}

            {% include 'flickr/includes/annual_photo_counts.html' with user=flickr_user only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'flickr/includes/nav_tabs.html' with user=flickr_user active='photos' only %}

            {% include 'flickr/includes/sorting.html' with request=request order=order only %}

            {% include 'flickr/includes/photo_columns.html' with request=request photo_list=photo_list order=order page_obj=page_obj perms=perms only %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}


