# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-05 11:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twitter', '0034_user_description_html'),
    ]

    operations = [
        migrations.AlterField(
            model_name='media',
            name='media_type',
            field=models.CharField(choices=[('animated_gif', 'Animated GIF'), ('photo', 'Photo'), ('video', 'Video')], max_length=8),
        ),
    ]
